from microconventions.stats_conventions import is_discrete, evenly_spaced_percentiles, cdf_values,\
    is_process, nudged, discrete_cdf, sign_changes, quantize, StatsConventions
import numpy as np


# Utilities to help with CDF's

from microprediction.univariate.arrivals import approx_mode

